@@ -25,7 +25,9 @@ int32_t SPVM__Net__SSLeay__EC_KEY__new_by_curve_name(SPVM_ENV* env, SPVM_VALUE*
     
     env->die(env, stack, "[OpenSSL Error]EC_KEY_new_by_curve_name failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
     
-    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    error_id = tmp_error_id;
     
     return error_id;
   }
