@@ -292,47 +292,6 @@ int32_t SPVM__Net__SSLeay__X509__get_ext_by_NID(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 }
 
-int32_t SPVM__Net__SSLeay__X509__get_ext_by_OBJ(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t error_id = 0;
-  
-  void* obj_self = stack[0].oval;
-  
-  void* obj_obj = stack[1].oval;
-  
-  int32_t lastpos = stack[2].ival;
-  
-  X509* self = env->get_pointer(env, stack, obj_self);
-  
-  if (!obj_obj) {
-    return env->die(env, stack, "The ASN1_OBJECT object $obj must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  
-  ASN1_OBJECT* obj = env->get_pointer(env, stack, obj_obj);
-  
-  int32_t index = X509_get_ext_by_OBJ(self, obj, lastpos);
-  
-  int32_t success = index != -1;
-  if (!success) {
-    int64_t ssl_error = ERR_peek_last_error();
-    
-    char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
-    ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
-    
-    env->die(env, stack, "[OpenSSL Error]X509_get_ext_by_OBJ failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
-    
-    int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
-    if (error_id) { return error_id; }
-    error_id = tmp_error_id;
-    
-    return error_id;
-  }
-  
-  stack[0].ival = index;
-  
-  return 0;
-}
-
 int32_t SPVM__Net__SSLeay__X509__get_ext_count(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
